# Want to use Application offline?

It's simple with Dojo Offline! Dojo Offline is a free open source utility that makes it easy for this web application to work, even if you're offline. Now you can access your data even when away from the network!

Dojo Offline is an open source project brought to you by Dojo, SitePen, and Brad Neuberg. It incorporates technologies created by Google.

## To get started:

1. Download Gears, a small, open source utility created by Google that allows this web site to work offline. This tool is safe and secure for your machine, and only takes a few seconds to download.
2. Once downloaded, run the installer. Restart your web browser when finished installing.
3. To access this website even when offline, drag the following link to your desktop or your browser's link toolbar above: Run Application.
4. Double-click the link on your desktop to start this web application, even if offline.